(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93207,       2709]*)
(*NotebookOutlinePosition[     93852,       2731]*)
(*  CellTagsIndexPosition[     93808,       2727]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Methoden der Bioinformatik",
    FontSize->24,
    FontWeight->"Bold"],
  StyleBox[" \n",
    FontSize->12],
  StyleBox["Eine Einf\[UDoubleDot]hrung",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Marc-Thorsten H\[UDoubleDot]tt und Manuel Dehnert",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12],
  StyleBox["Springer-Verlag 2006 (ISBN 3-540-25687-3)",
    FontSize->12,
    FontWeight->"Bold"],
  StyleBox["\n",
    FontSize->12]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Exkurs: ",
  "Pseudoereignisse"
}], "Subtitle",
  Background->RGBColor[0.0901961, 0.462745, 0.396078]],

Cell[TextData[{
  "In diesem Kapitel wurde die Sch\[ADoubleDot]tzung unter ",
  StyleBox["a-priori",
    FontSlant->"Italic"],
  "-Annahmen am Beispiel des W\[UDoubleDot]rfels erkl\[ADoubleDot]rt und die \
Priorverteilung f\[UDoubleDot]r den Parameter",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(p\_5\)\)\)]],
  " qualitativ angegeben (vgl. Abb. 2.7). Mit Hilfe von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " wollen wir nun unterschiedliche Datens\[ADoubleDot]tze ",
  StyleBox["D",
    FontSlant->"Italic"],
  "' erzeugen (im Sinne von Gleichung (2.34)) und die resultierende \
empirische Verteilung der Wahrscheinlichkeit ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(p\_5\)\)\)]],
  " in Form eines Histogramms in Abh\[ADoubleDot]ngigkeit von ",
  Cell[BoxData[
      \(TraditionalForm\`D\_0\)]],
  " und ",
  StyleBox["D",
    FontSlant->"Italic"],
  " visualisieren. Eine Realisierung des Datensatzes ",
  StyleBox["D",
    FontSlant->"Italic"],
  " erhalten wir durch die Funktion"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(<< Graphics`Graphics`\)], "Input"],

Cell[BoxData[{
    \(SeedRandom[1]\), "\[IndentingNewLine]", 
    \(dataD := Table[Random[Integer, {1, 6}], {10}]\)}], "Input"],

Cell[TextData[{
  "die 10 zuf\[ADoubleDot]llige, ganzzahlige Werte aus dem Intervall [1,6] \
ausgibt. Hervorzuheben ist an dieser Stelle noch, dass es sich bei der \
Definition von ",
  StyleBox["dataD",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " um eine verz\[ODoubleDot]gerte Zuweisung (",
  StyleBox[":=",
    FontWeight->"Bold"],
  ") und nicht um eine einmalige Festlegung (",
  "=",
  ") handelt. Ruft man die Variable nun auf, so erfolgt die Erzeugung der \
Zufallszahlen dadurch jedesmal aufs Neue. Wir setzen daher im Folgenden bei \
jedem Aufruf dieser Variablen den Zufallszahlengenerator mit dem Befehl ",
  StyleBox["SeedRandom",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " auf einen neuen Anfangswert, um diese Zuweisung f\[UDoubleDot]r das hier \
diskutierte Beispiel zu kontrollieren."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataD\)], "Input"],

Cell[BoxData[
    \({4, 6, 6, 3, 3, 3, 6, 1, 1, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In diesem Beispiel fehlt also ebenfalls die Zahl 5 in der Ausgangsmenge ",
  StyleBox["D",
    FontSlant->"Italic"],
  ". Der Datensatz ",
  Cell[BoxData[
      \(TraditionalForm\`D\_0\)]],
  " der Pseudoereignisse wird von uns definiert als"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(dataD0 = {1, 2, 3, 4, 5, 6};\)\)], "Input"],

Cell[TextData[{
  "Wie in jeder Programmiersprache kann man das ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-fache Aneinanderh\[ADoubleDot]ngen des Datensatz ",
  Cell[BoxData[
      \(TraditionalForm\`D\_0\)]],
  " nat\[UDoubleDot]rlich auf verschiedene Weise erreichen. Diese \
verschiedenen Wege einmal explizit zu diskutieren, ist sehr instruktiv, um \
das M\[ODoubleDot]glichkeitsspektrum von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " darzustellen, aber auch um anzudeuten, dass sich Programmieraufgaben oft \
durch \[ADoubleDot]u\[SZ]erst unterschiedliche Herangehensweisen bew\
\[ADoubleDot]ltigen lassen. Zugleich sind die damit \
gegen\[UDoubleDot]bergestellten Verfahren der Iteration im Umgang mit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recht weit verbreitete algorithmische Grundstrukturen. \n\n",
  StyleBox["Weg 1:",
    FontWeight->"Bold"],
  " Um ein ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-faches Aneinanderh\[ADoubleDot]ngen des Datensatz ",
  StyleBox["dataD0",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " zu erreichen, kann man zum Beispiel eine Tabelle mit fortlaufenden Zahlen \
als Indexliste erzeugen und dann \[UDoubleDot]ber den Befehl ",
  StyleBox["ReplaceAll",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " (der mit ",
  StyleBox["/.",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " abgek\[UDoubleDot]rzt wird) jeden Index (also jede ganze (Integer-)Zahl) \
durch ",
  StyleBox["dataD0",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ersetzen. Anwenden von ",
  StyleBox["Flatten",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " \[UDoubleDot]berf\[UDoubleDot]hrt danach das Resultat in eine aus ",
  StyleBox["n",
    FontSlant->"Italic"],
  " hintereinandergesetzten ",
  StyleBox["dataD0",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Listen bestehende Liste von Pseudoereignissen."
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(makePseudo[n_] := 
      Flatten[Table[j, {j, 1, n}] /. \ _Integer\  \[Rule] \ 
            dataD0]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(makePseudo[3]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Der Befehl ",
    FontSize->13],
  StyleBox["Join",
    FontFamily->"Courier New",
    FontWeight->"Bold"],
  StyleBox[" verkn\[UDoubleDot]pft die Datens\[ADoubleDot]tze miteinander, \
und die Wahrscheinlichkeit ",
    FontSize->13],
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)],
    FontSize->13],
  StyleBox[" kann f\[UDoubleDot]r den Datensatz ",
    FontSize->13],
  StyleBox["D",
    FontSize->13,
    FontSlant->"Italic"],
  StyleBox["' durch Nachz\[ADoubleDot]hlen berechnet werden.",
    FontSize->13]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SeedRandom[1]\), "\[IndentingNewLine]", 
    \(dataDprime = Join[makePseudo[1], dataD]\)}], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 4, 6, 6, 3, 3, 3, 6, 1, 1, 2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probP5 = Count[dataDprime, 5]/Length[dataDprime]\)], "Input"],

Cell[BoxData[
    \(1\/16\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "F\[UDoubleDot]r diese konkrete Realisierung von ",
  StyleBox["D",
    FontSlant->"Italic"],
  "' wird ",
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)]],
  " also als 1/16 gesch\[ADoubleDot]tzt.\n\n",
  StyleBox["Weg 2:",
    FontWeight->"Bold"],
  " Durch eine ",
  StyleBox["Do",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  "-Schleife wird in jedem Durchgang ein Datensatz angeh\[ADoubleDot]ngt."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(tmp1 = dataD0;\)\), "\[IndentingNewLine]", 
    \(Do[tmp1 = Join[tmp1, dataD0], {j, 1, 3}]\), "\[IndentingNewLine]", 
    \(tmp1\)}], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 
      6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Weg 3",
    FontWeight->"Bold"],
  ": Mit dem Befehl ",
  StyleBox["Nest[f, x, n]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " kann man die Funktion ",
  StyleBox["f",
    FontSlant->"Italic"],
  " sehr einfach ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-mal auf ",
  StyleBox["x",
    FontSlant->"Italic"],
  " schachteln. ",
  StyleBox["Nest[f, x, 3]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ergibt also ",
  StyleBox["f ( f ( f (x)))",
    FontSlant->"Italic"],
  ". Hat die Funktion ",
  StyleBox["f",
    FontSlant->"Italic"],
  " mehrere Argumente, muss man mit dem ",
  StyleBox["slot",
    FontSlant->"Italic"],
  "-Zeichen ",
  StyleBox["#",
    FontFamily->"Courier New",
    FontSize->12],
  " die Stelle benennen, die geschachtelt wird. Damit das Objekt dann noch \
als Funktion erkannt wird, muss man hinter den ",
  StyleBox["f",
    FontSlant->"Italic"],
  " -Ausdruck (also vor das erste Komma) das ",
  StyleBox["function",
    FontSlant->"Italic"],
  "-Zeichen ",
  StyleBox["&",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " setzen. F\[UDoubleDot]r eine Funktion ",
  StyleBox["f (x, y)",
    FontSlant->"Italic"],
  " ergibt ",
  StyleBox["Nest[f(#, y)&, x, 3]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " also gerade ",
  StyleBox["f ( f ( f (x, y), y), y)",
    FontSlant->"Italic"],
  ". Tr\[ADoubleDot]gt man f\[UDoubleDot]r ",
  StyleBox["f(x, #)",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " nun ",
  StyleBox["Join[dataD0, #]",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " ein, so erh\[ADoubleDot]lt man die ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-fach hintereinandergeh\[ADoubleDot]ngte Liste von Pseudoereignissen."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[
    \(tmp2 = Nest[Join[dataD0, #] &, dataD0, 3]\)], "Input"],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 6, 1, 2, 3, 4, 5, 
      6}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Nun gehen wir zur Verteilung ",
  StyleBox["P(",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)],
    FontSize->13,
    FontSlant->"Italic"],
  StyleBox[")",
    FontSlant->"Italic"],
  " \[UDoubleDot]ber, indem wir mehrere Datens\[ADoubleDot]tze ",
  StyleBox["D",
    FontSlant->"Italic"],
  " erzeugen und die relative H\[ADoubleDot]ufigkeit f\[UDoubleDot]r das \
Auftreten der Zahl 5 berechnen. Die Menge an Pseudodaten ",
  Cell[BoxData[
      \(TraditionalForm\`D\_0\^n\)]],
  " wird mit ",
  StyleBox["n",
    FontSlant->"Italic"],
  " variiert. F\[UDoubleDot]r ",
  StyleBox["n = 0",
    FontSlant->"Italic"],
  ", d.h. ",
  Cell[BoxData[
      \(TraditionalForm\`D\_0\)]],
  " = {} liefert die Funktion"
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeedRandom[1];\)\), "\[IndentingNewLine]", 
    \(probP5 = 
      Table[Count[Join[makePseudo[0], dataD], 5]/
          Length[Join[makePseudo[0], dataD]], {i, 1, 10}]\)}], "Input"],

Cell[BoxData[
    \({0, 1\/5, 1\/5, 1\/5, 1\/10, 0, 2\/5, 1\/5, 1\/5, 1\/5}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "die jeweiligeWahrscheinlichkeit ",
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)],
    FontSize->13,
    FontSlant->"Italic"],
  " f\[UDoubleDot]r 10 unterschiedliche Realisierungen von ",
  StyleBox["D",
    FontSlant->"Italic"],
  " in Form einer Liste. Die Visualisierung der empirischen Verteilung ist \
durch die Funktion ",
  StyleBox["Histogram",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " m\[ODoubleDot]glich. Die ",
  StyleBox["HistogramCategories",
    FontFamily->"Courier New",
    FontSize->12,
    FontWeight->"Bold"],
  " (also die Wertebereiche der S\[ADoubleDot]ulen im Histogramm) werden in \
Form einer Liste spezifiziert."
}], "Text",
  FontFamily->"Times New Roman",
  FontSize->13],

Cell[BoxData[
    \(\(bin = Table[i, {i, 0, 1, 0.05}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Histogram[probP5, HistogramCategories \[Rule] bin, 
      HistogramScale \[Rule] 0, HistogramRange \[Rule] {0, 1}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.0981006 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -6 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -6 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .11282 m
.00625 .11282 L
s
[(1)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(3)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(4)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(5)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(6)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .21092 L
.05 .21092 L
.05 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .21092 L
.05 .21092 L
.05 .01472 L
0 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .01472 L
.1 .01472 L
.1 .01472 L
F
0 g
.05 .01472 m
.05 .01472 L
.1 .01472 L
.1 .01472 L
.05 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .11282 L
.15 .11282 L
.15 .01472 L
F
0 g
.1 .01472 m
.1 .11282 L
.15 .11282 L
.15 .01472 L
.1 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .01472 L
.2 .01472 L
.2 .01472 L
F
0 g
.15 .01472 m
.15 .01472 L
.2 .01472 L
.2 .01472 L
.15 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .60332 L
.25 .60332 L
.25 .01472 L
F
0 g
.2 .01472 m
.2 .60332 L
.25 .60332 L
.25 .01472 L
.2 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
F
0 g
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
.25 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .01472 L
.35 .01472 L
.35 .01472 L
F
0 g
.3 .01472 m
.3 .01472 L
.35 .01472 L
.35 .01472 L
.3 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
F
0 g
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
.35 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .11282 L
.45 .11282 L
.45 .01472 L
F
0 g
.4 .01472 m
.4 .11282 L
.45 .11282 L
.45 .01472 L
.4 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
F
0 g
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
.45 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
F
0 g
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
.5 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
F
0 g
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
.55 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
F
0 g
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
.6 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
F
0 g
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
.65 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
F
0 g
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
.7 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
F
0 g
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
.75 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
F
0 g
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
.8 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
F
0 g
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
.85 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
F
0 g
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
.9 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
.95 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>P3oool2000000@0oooo0P0000030?ooo`@000009`3oool2000000@0oooo0P0000050?oo
o`<000009P3oool2000000@0oooo0P0000030?ooo`<00000:@3oool2000000@0oooo0P0000040?oo
o`800000;@3oool5000000<0oooo000i0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool09`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?ooo`00>@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool5
000002D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?oo
o`00>@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000P0oooo
0`00000X0?ooo`040000003oool0oooo000000T0oooo0P00000_0?ooo`030000003oool0oooo00<0
oooo000i0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002H0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000;P3oool00`000000oooo0?ooo`030?ooo`00>P3oool2000000X0oooo0P00000X0?ooo`800000
2`3oool2000002L0oooo0P00000:0?ooo`<00000:03oool2000000X0oooo0P00000^0?ooo`800000
1@3oool00?l0oooo8@3oool000X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`002P3oool00`00
0000oooo0?ooo`3o0?oooa@0oooo000:0?ooo`030000003oool0oooo0?l0oooo503oool000X0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`002P3ooooo0000018000001@3oool000X0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo02H0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`002P3oool00`000000o`000?l0000;0?l0
00030000003oool0oooo00X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0;0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l0
00030000003oool0oooo02D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00<0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool02P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00/0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0V03oool000X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`030000
003o0000o`0000/0o`0000<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000
003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`2H0?ooo`002P3o
ool00`000000o`000?l0000;0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3o
ool00`000000o`000?l0000;0?l000030000003oool0oooo09P0oooo000:0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000;0?l000030000003oool0
oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0V03oool000X0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool02`3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`2H0?ooo`002P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00X0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo09P0
oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0V03oool000X0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo02H0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`2H0?ooo`002P3oool00`000000o`000?l0000;
0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0;
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000;
0?l000030000003oool0oooo09P0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool02P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00/0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0V03oool000X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`2H0?ooo`00
2P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00X0oooo00<000000?l0003o0000
2`3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
9P3oool00`000000o`000?l0000;0?l000030000003oool0oooo09P0oooo000:0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0V03oool000X0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool02`3oool0
0`000000o`000?l0000:0?l000030000003oool0oooo02H0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`2H0?ooo`002P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
00X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
09P0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000
o`000?l0000;0?l000030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0V03oool000X0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo02H0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`2H0?ooo`002P3oool00`000000o`000?l0
000;0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002`3o00000`000000oooo0?oo
o`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0
000;0?l000030000003oool0oooo09P0oooo000:0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool02P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00/0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0V03oool000X0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0:0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`2H0?oo
o`002P3oool00`000000o`000?l0000;0?l000030000003oool0oooo00X0oooo00<000000?l0003o
00002`3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo09P0oooo000:0?ooo`030000
003o0000o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000;0?l000030000
003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000
003o0000o`0000/0o`0000<000000?ooo`3oool0V03oool00080oooo1@0000030?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool02P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0V03oool000@0oooo00<000000?ooo`3oool00`3oool0
0`000000o`000?l0000;0?l000030000003oool0oooo00X0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3oool0
0`000000o`000?l0000;0?l000030000003oool0oooo09P0oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`0:0?ooo`l000003@3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo02H0oooo3`00002J0?ooo`00103oool00`000000
oooo0?ooo`030?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000
o`000?l0000:0?l000030000003oool0oooo0<l0oooo00040?ooo`030000003oool0oooo00<0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0c`3oool000<0oooo0P0000050?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:
0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:
0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
9P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003o
ool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool0
0`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo
0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000
o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo
000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0
000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000
003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000
003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3o
ool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0
oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`00
0000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0
oooo000:0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`00
0?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool09P3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo0002
0?ooo`@00000103oool00`000000o`000?l0000;0?l000030000003oool0oooo02H0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`000P3oool00`000000oooo0?ooo`050?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool09P3oool00`000000o`000?l0000:0?l0
00030000003oool0oooo0<l0oooo00030?ooo`030000003oool0oooo00@0oooo3`00000X0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
c`3oool00080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0d0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000<0oooo0P0000050?ooo`030000003o
ool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool0
00X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo
0<l0oooo000:0?ooo`800000=@3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0
oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:
0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool2000003D0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03o
ool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0
oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0
oooo0P00000e0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo
00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo
000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l0
00030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool2000003D0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool0
0`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo00030?ooo`8000001@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool00080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0c`3oool000@0oooo00<000000?ooo`3oool00`3oool3000003@0
oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`3?0?ooo`000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`000`3oool2000000D0oooo00<0
00000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:
0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?
0?ooo`002P3oool2000003D0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?oo
o`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000
003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`00
0000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`800000=@3oool00`000000
o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo
00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?oo
o`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<00000
0?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?oo
o`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?oo
o`002P3oool2000003D0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`00
2P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003o
ool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o0000
0`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0c`3oool000X0oooo0P00000e0?ooo`030000003o0000o`0000X0
o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`00
0?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d
0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000@0oooo0`0000030?oo
o`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?oo
o`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<000000?l0003o
00002P3o00000`000000oooo0?ooo`3?0?ooo`000P3oool5000000<0oooo0`00000d0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool00080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
c`3oool000<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0d0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000@0oooo0P0000040?ooo`030000003oool0
oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0
oooo0P00000e0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo
00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo
000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l0
00030000003oool0oooo0<l0oooo000:0?ooo`800000=@3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool0
0`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo
03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000
oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo
0P00000e0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<0
00000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:
0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?
0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l00003
0000003oool0oooo0<l0oooo000:0?ooo`800000=@3oool00`000000o`000?l0000:0?l000030000
003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000
o`0000X0o`0000<000000?ooo`3oool0c`3oool000<0oooo0P0000050?ooo`030000003oool0oooo
03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`3?0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`<00000=03oool00`000000
o`000?l0000:0?l000030000003oool0oooo0<l0oooo00030?ooo`8000001@3oool00`000000oooo
0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0c`3oool000<0oooo0`0000040?ooo`030000003oool0oooo03@0oooo00<00000
0?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3o
ool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`800000
=@3oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003o
ool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool0
00X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo
0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000
oooo0?ooo`3?0?ooo`002P3oool2000003D0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<0
00000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:
0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo0P00000e0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03o
ool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0
oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0
oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l000030000003oool0oooo0<l0
oooo000:0?ooo`030000003oool0oooo03@0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`3?0?ooo`002P3oool2000003D0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`3?0?ooo`002P3oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0=03oool00`000000o`000?l0000:0?l0
00030000003oool0oooo0<l0oooo00020?ooo`<000001@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool00080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0d0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0c`3oool00080oooo00@000000?ooo`3oool00000103oool3000003@0oooo3P00003A0?ooo`00
0P3oool3000000D0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo503oool000<0oooo0`0000040?ooo`030000003oool0
oooo0?l0oooo503oool000X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0395448, -0.46482, \
0.0036779, 0.0374911}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Abbildung 2.10 zeigt die Histogramme f\[UDoubleDot]r a: ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 0, b: ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 1 und c: ",
  StyleBox["n",
    FontSlant->"Italic"],
  " = 10. Man erkennt deutlich den bereits in der schematischen Darstellung, \
Abb. 2.7, angedeuteten Effekt: Mit wachsender Zahl der Pseudoereignisse \
entsteht eine immer schmalere Verteilung um den Wert ",
  StyleBox["p",
    FontSlant->"Italic"],
  " = 1/ 6."
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(\(n = 1;\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeedRandom[1];\)\), "\[IndentingNewLine]", 
    \(probP5 = 
      Table[Count[Join[makePseudo[n], dataD], 5]/
          Length[Join[makePseudo[n], dataD]], {i, 1, 10}]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({1\/16, 3\/16, 3\/16, 3\/16, 1\/8, 1\/16, 5\/16, 3\/16, 3\/16, 
      3\/16}\)], "Output",
  FontColor->GrayLevel[0.500008]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Histogram[probP5, HistogramCategories \[Rule] bin, 
      HistogramScale \[Rule] 0, HistogramRange \[Rule] {0, 1}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.0981006 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .11282 -6 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -6 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -6 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -6 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .11282 m
.00625 .11282 L
s
[(1)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(2)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(3)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(4)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(5)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(6)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03434 m
.00375 .03434 L
s
0 .05396 m
.00375 .05396 L
s
0 .07358 m
.00375 .07358 L
s
0 .0932 m
.00375 .0932 L
s
0 .13244 m
.00375 .13244 L
s
0 .15206 m
.00375 .15206 L
s
0 .17168 m
.00375 .17168 L
s
0 .1913 m
.00375 .1913 L
s
0 .23054 m
.00375 .23054 L
s
0 .25016 m
.00375 .25016 L
s
0 .26978 m
.00375 .26978 L
s
0 .2894 m
.00375 .2894 L
s
0 .32864 m
.00375 .32864 L
s
0 .34826 m
.00375 .34826 L
s
0 .36788 m
.00375 .36788 L
s
0 .3875 m
.00375 .3875 L
s
0 .42674 m
.00375 .42674 L
s
0 .44636 m
.00375 .44636 L
s
0 .46598 m
.00375 .46598 L
s
0 .4856 m
.00375 .4856 L
s
0 .52484 m
.00375 .52484 L
s
0 .54446 m
.00375 .54446 L
s
0 .56408 m
.00375 .56408 L
s
0 .5837 m
.00375 .5837 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.05 .01472 L
.05 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05 .01472 L
.05 .01472 L
0 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .21092 L
.1 .21092 L
.1 .01472 L
F
0 g
.05 .01472 m
.05 .21092 L
.1 .21092 L
.1 .01472 L
.05 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .11282 L
.15 .11282 L
.15 .01472 L
F
0 g
.1 .01472 m
.1 .11282 L
.15 .11282 L
.15 .01472 L
.1 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .60332 L
.2 .60332 L
.2 .01472 L
F
0 g
.15 .01472 m
.15 .60332 L
.2 .60332 L
.2 .01472 L
.15 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .01472 L
.25 .01472 L
.25 .01472 L
F
0 g
.2 .01472 m
.2 .01472 L
.25 .01472 L
.25 .01472 L
.2 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
F
0 g
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
.25 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .11282 L
.35 .11282 L
.35 .01472 L
F
0 g
.3 .01472 m
.3 .11282 L
.35 .11282 L
.35 .01472 L
.3 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
F
0 g
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
.35 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .01472 L
.45 .01472 L
.45 .01472 L
F
0 g
.4 .01472 m
.4 .01472 L
.45 .01472 L
.45 .01472 L
.4 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
F
0 g
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
.45 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
F
0 g
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
.5 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
F
0 g
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
.55 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
F
0 g
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
.6 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
F
0 g
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
.65 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
F
0 g
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
.7 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
F
0 g
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
.75 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
F
0 g
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
.8 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
F
0 g
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
.85 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
F
0 g
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
.9 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
.95 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>P3oool2000000@0oooo0P0000030?ooo`@000009`3oool2000000@0oooo0P0000050?oo
o`<000009P3oool2000000@0oooo0P0000030?ooo`<00000:@3oool2000000@0oooo0P0000040?oo
o`800000;@3oool5000000<0oooo000i0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool09`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?ooo`00>@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool5
000002D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?oo
o`00>@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000P0oooo
0`00000X0?ooo`040000003oool0oooo000000T0oooo0P00000_0?ooo`030000003oool0oooo00<0
oooo000i0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002H0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000;P3oool00`000000oooo0?ooo`030?ooo`00>P3oool2000000X0oooo0P00000X0?ooo`800000
2`3oool2000002L0oooo0P00000:0?ooo`<00000:03oool2000000X0oooo0P00000^0?ooo`800000
1@3oool00?l0oooo8@3oool000X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`002P3oool00`00
0000oooo0?ooo`3o0?oooa@0oooo000:0?ooo`030000003oool0oooo0?l0oooo503oool000X0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`002P3ooooo0000018000001@3oool000X0oooo00<00000
0?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`030?ooo`002P3oool00`000000oooo0?ooo`0;0?oo
o`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l0
00030000003oool0oooo01P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00<0oooo000:0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o
00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0603oool00`000000o`000?l0000:0?l000030000003oool0oooo0;@0oooo000:0?ooo`030000
003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000
003oool0oooo0;@0oooo000:0?ooo`800000303oool00`000000o`000?l0000:0?l000030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o
0000o`0000X0o`0000<000000?ooo`3oool0]03oool000X0oooo00<000000?ooo`3oool02`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool0
00X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o0000o`00
00X0o`0000<000000?ooo`3oool0]03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000
o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000
oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool000X0oooo
00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool0]03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0
000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?oo
o`0H0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool000X0oooo0P00000<
0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;
0?l000030000003oool0oooo01P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2d
0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?l0
003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo01P0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`2d0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003o0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l00003
0000003oool0oooo01P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2d0?ooo`00
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003oool0oooo01P0oooo00<000000?l0003o0000
2P3o00000`000000oooo0?ooo`2d0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
0000o`0000X0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o
ool0oooo01P0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`2d0?ooo`002P3oool2
000000`0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000/0o`0000<000000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000003oool0
oooo0;@0oooo000:0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0603oool00`00
0000o`000?l0000:0?l000030000003oool0oooo0;@0oooo000:0?ooo`030000003oool0oooo00/0
oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0
o`0000<000000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000003oool0oooo0;@0
oooo000:0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000o`00
0?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0603oool00`000000o`00
0?l0000:0?l000030000003oool0oooo0;@0oooo000:0?ooo`030000003oool0oooo00/0oooo00<0
00000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<0
00000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000003oool0oooo0;@0oooo000:
0?ooo`800000303oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<00000
0?ooo`3oool0]03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l0
00030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0H0?oo
o`030000003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool000X0oooo00<000000?ooo`3o
ool02`3oool00`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3o
ool0]03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`0H0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool00080oooo1@0000030?ooo`030000003o
ool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0603oool00`000000o`000?l0000:0?l000030000003o
ool0oooo0;@0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool0
0`000000o`000?l0000:0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0]03oool0
00@0oooo00<000000?ooo`3oool00`3oool3000000/0oooo00<000000?l0003o00002P3o000?0000
00d0o`0000<000000?ooo`3oool0603oool>00000;H0oooo00040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo00/0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo
0?ooo`0;0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000<0oooo0P00
00050?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`0;0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo00/0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000000`0oooo00<000000?l0
003o00002P3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0g03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l00003
0000003oool0oooo00/0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool0
2`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003o
ool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0;0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool02`3oool0
0`000000o`000?l0000:0?l000030000003oool0oooo00/0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`002P3oool2000000`0oooo00<000000?l0003o00002P3o00000`00
0000oooo0?ooo`0;0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0
oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0oooo00/0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo
0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02`3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo00/0oooo00<0
00000?l0003o00002P3o00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:
0?l000030000003oool0oooo00/0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L
0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool02`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`80
0000303oool00`000000o`000?l0000:0?l000030000003oool0oooo00/0oooo00<000000?l0003o
00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000
003o0000o`0000X0o`0000<000000?ooo`3oool02`3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o
00000`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03o
ool000X0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l0000:0?l000030000003oool0
oooo00/0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?ooo`3oool02`3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`800000303oool00`000000
o`000?l0000:0?l000030000003oool0oooo00/0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`00
00<000000?ooo`3oool02`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo
000:0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?oo
o`0;0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool00080oooo10000004
0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00002P3o00000`000000oooo0?ooo`0;
0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool00080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000X0o`0000<000000?oo
o`3oool02`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00030?ooo`03
0000003oool0oooo00@0oooo0`00000;0?ooo`h000003@3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo0=`0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
9P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo00030?ooo`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool0
0`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo
02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo
0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<0
00000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:
0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L
0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0g03oool000X0oooo0P00000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?oo
o`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0g03oool000X0oooo0P00000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`000`3oool2000000D0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
0=`0oooo00040?ooo`030000003oool0oooo00<0oooo0`00000V0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0g03oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool00080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool0g03oool000<0oooo0P0000050?ooo`030000003oool0oooo02H0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V
0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo0P00000W0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3o
ool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000
003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03o
ool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0
oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`00
00<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0
000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo0P00000W0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool0
9P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003o
ool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool0
00X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
0=`0oooo000:0?ooo`8000009`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0
oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo
0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;
0?l000030000003oool0oooo0=`0oooo00040?ooo`<000000`3oool00`000000oooo0?ooo`0V0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0g03oool00080oooo1@0000030?ooo`<000009P3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
9P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00030?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo00040?ooo`800000103oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?oo
o`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V
0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?oo
o`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`03
0000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03o
ool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0
oooo0=`0oooo00030?ooo`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0g03oool00080oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000D0
oooo00<000000?ooo`3oool00P3oool3000002H0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`3L0?ooo`000`3oool2000000D0oooo00<000000?ooo`3oool09P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo00030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo0003
0?ooo`<00000103oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l0
00030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o
00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<000000?l0003o0000
2`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool0
0`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo
02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000
oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo
0P00000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<0
00000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:
0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L
0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo
0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo0P00
000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?oo
o`000P3oool3000000D0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo0=`0oooo00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`040000
003oool0oooo000000@0oooo0`00000V0?ooo`l00000gP3oool00080oooo0`0000050?ooo`030000
003oool0oooo0?l0oooo503oool000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`3o0?oooa@0oooo00030?ooo`<00000103oool00`000000oooo0?ooo`3o0?oooa@0oooo000:0?oo
o`030000003oool0oooo0?l0oooo503oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0395448, -0.46482, \
0.0036779, 0.0374911}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(n = 10;\)\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SeedRandom[1];\)\), "\[IndentingNewLine]", 
    \(probP5 = 
      Table[Count[Join[makePseudo[n], dataD], 5]/
          Length[Join[makePseudo[n], dataD]], {i, 1, 10}]\)}], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[BoxData[
    \({1\/7, 6\/35, 6\/35, 6\/35, 11\/70, 1\/7, 1\/5, 6\/35, 6\/35, 
      6\/35}\)], "Output",
  FontColor->GrayLevel[0.500008]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Histogram[probP5, HistogramCategories \[Rule] bin, 
      HistogramScale \[Rule] 0, HistogramRange \[Rule] {0, 1}]\)], "Input",
  FontColor->GrayLevel[0.500008]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0.0147151 0.0840863 [
[.2 .00222 -9 -9 ]
[.2 .00222 9 0 ]
[.4 .00222 -9 -9 ]
[.4 .00222 9 0 ]
[.6 .00222 -9 -9 ]
[.6 .00222 9 0 ]
[.8 .00222 -9 -9 ]
[.8 .00222 9 0 ]
[1 .00222 -3 -9 ]
[1 .00222 3 0 ]
[-0.0125 .0988 -6 -4.5 ]
[-0.0125 .0988 0 4.5 ]
[-0.0125 .18289 -6 -4.5 ]
[-0.0125 .18289 0 4.5 ]
[-0.0125 .26697 -6 -4.5 ]
[-0.0125 .26697 0 4.5 ]
[-0.0125 .35106 -6 -4.5 ]
[-0.0125 .35106 0 4.5 ]
[-0.0125 .43515 -6 -4.5 ]
[-0.0125 .43515 0 4.5 ]
[-0.0125 .51923 -6 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01472 m
.2 .02097 L
s
[(0.2)] .2 .00222 0 1 Mshowa
.4 .01472 m
.4 .02097 L
s
[(0.4)] .4 .00222 0 1 Mshowa
.6 .01472 m
.6 .02097 L
s
[(0.6)] .6 .00222 0 1 Mshowa
.8 .01472 m
.8 .02097 L
s
[(0.8)] .8 .00222 0 1 Mshowa
1 .01472 m
1 .02097 L
s
[(1)] 1 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .0988 m
.00625 .0988 L
s
[(1)] -0.0125 .0988 1 0 Mshowa
0 .18289 m
.00625 .18289 L
s
[(2)] -0.0125 .18289 1 0 Mshowa
0 .26697 m
.00625 .26697 L
s
[(3)] -0.0125 .26697 1 0 Mshowa
0 .35106 m
.00625 .35106 L
s
[(4)] -0.0125 .35106 1 0 Mshowa
0 .43515 m
.00625 .43515 L
s
[(5)] -0.0125 .43515 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(6)] -0.0125 .51923 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(7)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03153 m
.00375 .03153 L
s
0 .04835 m
.00375 .04835 L
s
0 .06517 m
.00375 .06517 L
s
0 .08198 m
.00375 .08198 L
s
0 .11562 m
.00375 .11562 L
s
0 .13244 m
.00375 .13244 L
s
0 .14925 m
.00375 .14925 L
s
0 .16607 m
.00375 .16607 L
s
0 .1997 m
.00375 .1997 L
s
0 .21652 m
.00375 .21652 L
s
0 .23334 m
.00375 .23334 L
s
0 .25016 m
.00375 .25016 L
s
0 .28379 m
.00375 .28379 L
s
0 .30061 m
.00375 .30061 L
s
0 .31743 m
.00375 .31743 L
s
0 .33424 m
.00375 .33424 L
s
0 .36788 m
.00375 .36788 L
s
0 .38469 m
.00375 .38469 L
s
0 .40151 m
.00375 .40151 L
s
0 .41833 m
.00375 .41833 L
s
0 .45196 m
.00375 .45196 L
s
0 .46878 m
.00375 .46878 L
s
0 .4856 m
.00375 .4856 L
s
0 .50242 m
.00375 .50242 L
s
0 .53605 m
.00375 .53605 L
s
0 .55287 m
.00375 .55287 L
s
0 .56968 m
.00375 .56968 L
s
0 .5865 m
.00375 .5865 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .01472 L
.05 .01472 L
.05 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .01472 L
.05 .01472 L
.05 .01472 L
0 .01472 L
s
1 0 0 r
.05 .01472 m
.05 .01472 L
.1 .01472 L
.1 .01472 L
F
0 g
.05 .01472 m
.05 .01472 L
.1 .01472 L
.1 .01472 L
.05 .01472 L
s
1 0 0 r
.1 .01472 m
.1 .18289 L
.15 .18289 L
.15 .01472 L
F
0 g
.1 .01472 m
.1 .18289 L
.15 .18289 L
.15 .01472 L
.1 .01472 L
s
1 0 0 r
.15 .01472 m
.15 .60332 L
.2 .60332 L
.2 .01472 L
F
0 g
.15 .01472 m
.15 .60332 L
.2 .60332 L
.2 .01472 L
.15 .01472 L
s
1 0 0 r
.2 .01472 m
.2 .0988 L
.25 .0988 L
.25 .01472 L
F
0 g
.2 .01472 m
.2 .0988 L
.25 .0988 L
.25 .01472 L
.2 .01472 L
s
1 0 0 r
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
F
0 g
.25 .01472 m
.25 .01472 L
.3 .01472 L
.3 .01472 L
.25 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .01472 L
.35 .01472 L
.35 .01472 L
F
0 g
.3 .01472 m
.3 .01472 L
.35 .01472 L
.35 .01472 L
.3 .01472 L
s
1 0 0 r
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
F
0 g
.35 .01472 m
.35 .01472 L
.4 .01472 L
.4 .01472 L
.35 .01472 L
s
1 0 0 r
.4 .01472 m
.4 .01472 L
.45 .01472 L
.45 .01472 L
F
0 g
.4 .01472 m
.4 .01472 L
.45 .01472 L
.45 .01472 L
.4 .01472 L
s
1 0 0 r
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
F
0 g
.45 .01472 m
.45 .01472 L
.5 .01472 L
.5 .01472 L
.45 .01472 L
s
1 0 0 r
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
F
0 g
.5 .01472 m
.5 .01472 L
.55 .01472 L
.55 .01472 L
.5 .01472 L
s
1 0 0 r
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
F
0 g
.55 .01472 m
.55 .01472 L
.6 .01472 L
.6 .01472 L
.55 .01472 L
s
1 0 0 r
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
F
0 g
.6 .01472 m
.6 .01472 L
.65 .01472 L
.65 .01472 L
.6 .01472 L
s
1 0 0 r
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
F
0 g
.65 .01472 m
.65 .01472 L
.7 .01472 L
.7 .01472 L
.65 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
F
0 g
.7 .01472 m
.7 .01472 L
.75 .01472 L
.75 .01472 L
.7 .01472 L
s
1 0 0 r
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
F
0 g
.75 .01472 m
.75 .01472 L
.8 .01472 L
.8 .01472 L
.75 .01472 L
s
1 0 0 r
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
F
0 g
.8 .01472 m
.8 .01472 L
.85 .01472 L
.85 .01472 L
.8 .01472 L
s
1 0 0 r
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
F
0 g
.85 .01472 m
.85 .01472 L
.9 .01472 L
.9 .01472 L
.85 .01472 L
s
1 0 0 r
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
F
0 g
.9 .01472 m
.9 .01472 L
.95 .01472 L
.95 .01472 L
.9 .01472 L
s
1 0 0 r
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
F
0 g
.95 .01472 m
.95 .01472 L
1 .01472 L
1 .01472 L
.95 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00>P3oool2000000@0oooo0P0000030?ooo`@000009`3oool2000000@0oooo0P0000050?oo
o`<000009P3oool2000000@0oooo0P0000030?ooo`<00000:@3oool2000000@0oooo0P0000040?oo
o`800000;@3oool5000000<0oooo000i0?ooo`040000003oool0oooo000000P0oooo00<000000?oo
o`3oool09`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02@0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?ooo`00>@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool00000203oool5
000002D0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000W0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`030?oo
o`00>@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`040000003oool0oooo000000P0oooo
0`00000X0?ooo`040000003oool0oooo000000T0oooo0P00000_0?ooo`030000003oool0oooo00<0
oooo000i0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000009P3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0000002H0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000;P3oool00`000000oooo0?ooo`030?ooo`00>P3oool2000000X0oooo0P00000X0?ooo`800000
2`3oool2000002L0oooo0P00000:0?ooo`<00000:03oool2000000X0oooo0P00000^0?ooo`800000
1@3oool00?l0oooo8@3oool000X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`002P3oool00`00
0000oooo0?ooo`3o0?oooa@0oooo000:0?ooo`030000003oool0oooo0?l0oooo503oool000X0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`002P3ooooo0000018000001@3oool000X0oooo00<00000
0?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?l0003o00002P3o00000`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00<0oooo000:0?oo
o`030000003oool0oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l0
00030000003o0000o`0000X0o`0000<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`030?oo
o`002P3oool00`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o
00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000
003oool0oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000
003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo0P00000I0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003o
ool0oooo0<l0oooo000:0?ooo`030000003oool0oooo01P0oooo00<000000?l0003o00002`3o0000
0`000000o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool0
00X0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000
oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000
o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`8000006@3oool00`000000o`00
0?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo
0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<0
00000?l0003o00002`3o00000`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:
0?ooo`030000003oool0oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;
0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?oo
o`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:0?l00003
0000003oool0oooo0<l0oooo000:0?ooo`8000006@3oool00`000000o`000?l0000;0?l000030000
003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o
00000`000000o`000?l0000:0?l000030000003oool0oooo0<l0oooo000:0?ooo`030000003oool0
oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003o0000
o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo00<000000?ooo`3oool0603oool00`00
0000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0003o00002P3o00000`00
0000oooo0?ooo`3?0?ooo`002P3oool2000001T0oooo00<000000?l0003o00002`3o00000`000000
o`000?l0000;0?l000030000003o0000o`0000X0o`0000<000000?ooo`3oool0c`3oool000X0oooo
00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`00
00<000000?l0003o00002P3o00000`000000oooo0?ooo`3?0?ooo`002P3oool00`000000oooo0?oo
o`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0
000:0?l000030000003oool0oooo0<l0oooo00020?ooo`D000000`3oool00`000000oooo0?ooo`0H
0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000o`000?l0000:
0?l000030000003oool0oooo0<l0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?l0
003o00002P3o00000`000000oooo0?ooo`3?0?ooo`00103oool00`000000oooo0?ooo`030?ooo`<0
0000603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`003P00003A0?ooo`00
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000<0oooo0P0000050?ooo`030000003oool0
oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0
oooo0=`0oooo000:0?ooo`8000006@3oool00`000000o`000?l0000;0?l000030000003o0000o`00
00/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool0603oool00`000000
o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo
00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`00
00<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0
000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0g03oool000X0oooo0P00000I0?ooo`030000003o0000o`0000/0o`0000<000000?l0
003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003o0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o0000
2`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
0000o`0000/0o`0000<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003o0000o`0000/0o`0000<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`002P3oool2000001T0oooo00<000000?l0003o00002`3o00000`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo01P0
oooo00<000000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo0=`0
oooo000:0?ooo`030000003oool0oooo01P0oooo00<000000?l0003o00002`3o00000`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo01P0oooo00<0
00000?l0003o00002`3o00000`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:
0?ooo`8000006@3oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l0
00030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3o
ool0603oool00`000000o`000?l0000;0?l000030000003o0000o`0000/0o`0000<000000?ooo`3o
ool0g03oool00080oooo100000040?ooo`030000003oool0oooo01P0oooo00<000000?l0003o0000
2`3o00000`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000o`000?l0000;0?l000030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000<0oooo00<000000?ooo`3oool0103oool3
000001P0oooo3`00000=0?l000030000003oool0oooo0=`0oooo00040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
0=`0oooo00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00030?ooo`8000001@3oool00`000000
oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo
0P00000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<0
00000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:
0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L
0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?oo
o`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo00030?ooo`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool00080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool0
00@0oooo00<000000?ooo`3oool00`3oool3000002H0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`3L0?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02H0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`3L0?ooo`000`3oool2000000D0oooo00<000000?ooo`3oool09P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000o`000?l0
000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3o
ool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000
003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3o
ool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool0
0`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool0
00X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000
oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo
0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;
0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0
003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo0P00000W0?ooo`030000
003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3o
ool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00040?ooo`<000000`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool0
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0g03oool00080oooo1@0000030?ooo`<000009P3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0
oooo00030?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool09P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo00040?ooo`800000103oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`8000009`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`03
0000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`00
0000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<00000
0?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?oo
o`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3o
ool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000
003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3o
ool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03o
ool000X0oooo0P00000W0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool0
00X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo
0=`0oooo00030?ooo`8000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0g03oool00080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000D0oooo
00<000000?ooo`3oool00P3oool3000002H0oooo00<000000?l0003o00002`3o00000`000000oooo
0?ooo`3L0?ooo`000`3oool2000000D0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0
000;0?l000030000003oool0oooo0=`0oooo00030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00030?oo
o`<00000103oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?oo
o`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l00003
0000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000o`000?l0000;0?l000030000
003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o
00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000
o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`00
0000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3oool00`000000
o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo
00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?oo
o`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?oo
o`002P3oool2000002L0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`00
2P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0
g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003o
ool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o0000
0`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`00
00/0o`0000<000000?ooo`3oool0g03oool000X0oooo0P00000W0?ooo`030000003o0000o`0000/0
o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`00
0?l0000;0?l000030000003oool0oooo0=`0oooo00020?ooo`<000001@3oool00`000000oooo0?oo
o`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool00080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<0
00000?ooo`3oool0g03oool00080oooo00@000000?ooo`3oool00000103oool3000002H0oooo00<0
00000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`000P3oool3000000D0oooo00<00000
0?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l0
00030000003oool0oooo0=`0oooo00030?ooo`<00000103oool00`000000oooo0?ooo`0V0?ooo`03
0000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool0
9P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`8000009`3o
ool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0
oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0
oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0
oooo000:0?ooo`8000009`3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo
000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?oo
o`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<00000
0?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;0?l0
00030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo02H0oooo00<000000?l0003o
00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0oooo00<000000?l0003o0000
2`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<000000?ooo`3oool09P3oool0
0`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo
02H0oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool2000002L0
oooo00<000000?l0003o00002`3o00000`000000oooo0?ooo`3L0?ooo`002P3oool00`000000oooo
0?ooo`0V0?ooo`030000003o0000o`0000/0o`0000<000000?ooo`3oool0g03oool000X0oooo00<0
00000?ooo`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo0004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool00`000000o`000?l0000;
0?l000030000003oool0oooo0=`0oooo00040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool09P3oool00`000000o`000?l0000;0?l000030000003oool0oooo0=`0oooo00040?ooo`03
0000003oool0oooo00<0oooo0`00000V0?ooo`l00000gP3oool000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`3o0?oooa@0oooo00020?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0o`3ooolD0?ooo`000P3oool4000000@0oooo00<000000?ooo`3oool0o`3o
oolD0?ooo`002P3oool00`000000oooo0?ooo`3o0?oooa@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0395448, -0.54229, \
0.0036779, 0.0437395}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{507, 601},
WindowMargins->{{Automatic, 10}, {20, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 553, 21, 115, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2332, 76, 174, 6, 68, "Subtitle"],
Cell[2509, 84, 1048, 29, 90, "Text"],
Cell[3560, 115, 54, 1, 30, "Input"],
Cell[3617, 118, 127, 2, 50, "Input"],
Cell[3747, 122, 898, 23, 92, "Text"],

Cell[CellGroupData[{
Cell[4670, 149, 38, 1, 30, "Input"],
Cell[4711, 152, 64, 1, 29, "Output"]
}, Open  ]],
Cell[4790, 156, 289, 9, 33, "Text"],
Cell[5082, 167, 65, 1, 30, "Input"],
Cell[5150, 170, 2084, 61, 169, "Text"],
Cell[7237, 233, 132, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[7394, 240, 46, 1, 30, "Input"],
Cell[7443, 243, 88, 1, 29, "Output"]
}, Open  ]],
Cell[7546, 247, 553, 19, 34, "Text"],

Cell[CellGroupData[{
Cell[8124, 270, 121, 2, 50, "Input"],
Cell[8248, 274, 82, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8367, 280, 81, 1, 30, "Input"],
Cell[8451, 283, 39, 1, 42, "Output"]
}, Open  ]],
Cell[8505, 287, 480, 17, 72, "Text"],

Cell[CellGroupData[{
Cell[9010, 308, 165, 3, 70, "Input"],
Cell[9178, 313, 113, 2, 29, "Output"]
}, Open  ]],
Cell[9306, 318, 1922, 73, 112, "Text"],

Cell[CellGroupData[{
Cell[11253, 395, 74, 1, 30, "Input"],
Cell[11330, 398, 113, 2, 29, "Output"]
}, Open  ]],
Cell[11458, 403, 819, 29, 52, "Text"],

Cell[CellGroupData[{
Cell[12302, 436, 204, 4, 50, "Input"],
Cell[12509, 442, 89, 1, 42, "Output"]
}, Open  ]],
Cell[12613, 446, 759, 24, 53, "Text"],
Cell[13375, 472, 69, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[13469, 477, 147, 2, 30, "Input"],
Cell[13619, 481, 26501, 715, 186, 5052, 446, "GraphicsData", "PostScript", \
"Graphics"],
Cell[40123, 1198, 130, 3, 29, "Output"]
}, Open  ]],
Cell[40268, 1204, 528, 17, 52, "Text"],
Cell[40799, 1223, 77, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[40901, 1229, 238, 5, 50, "Input"],
Cell[41142, 1236, 144, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41323, 1244, 181, 3, 50, "Input"],
Cell[41507, 1249, 26396, 714, 186, 5052, 446, "GraphicsData", "PostScript", \
"Graphics"],
Cell[67906, 1965, 130, 3, 29, "Output"]
}, Open  ]],
Cell[68051, 1971, 78, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[68154, 1977, 238, 5, 90, "Input"],
Cell[68395, 1984, 143, 3, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68575, 1992, 181, 3, 50, "Input"],
Cell[68759, 1997, 24287, 703, 186, 5276, 464, "GraphicsData", "PostScript", \
"Graphics"],
Cell[93049, 2702, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

